==> haskell-persistent-qq-2.12.0.6-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-BVarzgvIc0DHc128krESRk
key:                  persistent-qq-2.12.0.6-BVarzgvIc0DHc128krESRk
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  04d2c023468b87b07c0f30a2c58c7220
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-BVarzgvIc0DHc128krESRk
depends:
    base-4.16.4.0 haskell-src-meta-0.8.12-KNiKyctxc027sJi67OT6DV
    mtl-2.2.2 persistent-2.14.5.1-Gj4KghoR3zfABSnrc3wG7v
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.6-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-5ko8GgRyQ94AXXoCyjztKj
key:                  persistent-qq-2.12.0.6-5ko8GgRyQ94AXXoCyjztKj
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  1c930e676722306fdccaf4d76c62de5b
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-5ko8GgRyQ94AXXoCyjztKj
depends:
    base-4.16.4.0 haskell-src-meta-0.8.12-FavU8jGcoCs2KrEocGMM56
    mtl-2.2.2 persistent-2.14.5.1-9SQzkYCECsfAwc87zLlX1f
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
